==> netbeans_6.8.orig.tar.gz: netbeans-6.8/kenai.ui/src/org/netbeans/modules/kenai/ui/nodes/KenaiInstanceNode.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Sun Microsystems, Inc.
 */

package org.netbeans.modules.kenai.ui.nodes;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.IOException;
import javax.swing.Action;
import org.netbeans.modules.kenai.api.Kenai;
import org.openide.actions.PropertiesAction;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node.PropertySet;
import org.openide.util.actions.SystemAction;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author Jan Becicka
 */
public class KenaiInstanceNode extends AbstractNode implements PropertyChangeListener {

    private KenaiInstance kenaiInstance;
    private KenaiInstanceProperties properties;

    public KenaiInstanceNode(final KenaiInstance instance) {
        super(new Children.Array(), Lookups.singleton(instance));
        this.kenaiInstance=instance;
        setName(kenaiInstance.getUrl());
        Kenai.getDefault().addPropertyChangeListener(Kenai.PROP_URL_CHANGED, this);
        setDisplayName(instance.getDisplayName());
        setShortDescription(instance.getDisplayName() + " (" + instance.getUrl() + ")"); // NOI18N
        setIconBaseWithExtension("org/netbeans/modules/kenai/ui/resources/kenai-small.png");//NOI18N
        properties = new KenaiInstanceProperties(instance.getDisplayName(),instance.getUrl());
    }

    @Override
    public Action[] getActions(boolean context) {
        return new Action[] {
            new SetAsDefaultAction(this),
            new RemoveInstanceAction(kenaiInstance),
            SystemAction.get(PropertiesAction.class)
        };
    }

    @Override
    public String getHtmlDisplayName() {
        if (Kenai.getDefault().getUrl().toString().equals(kenaiInstance.getUrl())) {
            return "<b>" + getDisplayName() + "</b>"; // NOI18N
        }
        return super.getHtmlDisplayName();
    }

    public void propertyChange(PropertyChangeEvent evt) {
        fireDisplayNameChange("", getHtmlDisplayName());
    }

    @Override
    public void destroy() throws IOException {
        Kenai.getDefault().removePropertyChangeListener(this);
    }

    @Override
    public PropertySet[] getPropertySets() {
        return new PropertySet[] {properties.getSheetSet()};
    }

    @Override
    public boolean canCopy() {
        return false;
    }

}

==> netbeans_6.9.orig.tar.gz: netbeans-6.9/kenai.ui/src/org/netbeans/modules/kenai/ui/nodes/KenaiInstanceNode.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2009 Sun Microsystems, Inc.
 */

package org.netbeans.modules.kenai.ui.nodes;

import java.awt.Image;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.IOException;
import javax.swing.Action;
import org.netbeans.modules.kenai.api.Kenai;
import org.openide.actions.PropertiesAction;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node.PropertySet;
import org.openide.util.ImageUtilities;
import org.openide.util.actions.SystemAction;
import org.openide.util.lookup.Lookups;

/**
 *
 * @author Jan Becicka
 */
public class KenaiInstanceNode extends AbstractNode implements PropertyChangeListener {

    private Kenai kenaiInstance;
    private KenaiInstanceProperties properties;

    public KenaiInstanceNode(final Kenai instance) {
        super(new Children.Array(), Lookups.singleton(instance));
        this.kenaiInstance=instance;
        setName(kenaiInstance.getUrl().toString());
        instance.addPropertyChangeListener(Kenai.PROP_URL_CHANGED, this);
        setDisplayName(instance.getName());
        setShortDescription(instance.getName() + " (" + instance.getUrl() + ")"); // NOI18N
        properties = new KenaiInstanceProperties(instance.getName(),instance.getUrl().toString());
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.icon2Image(kenaiInstance.getIcon());
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }

    @Override
    public Action[] getActions(boolean context) {
        return new Action[] {
            new LoginAction(kenaiInstance),
            new RemoveInstanceAction(kenaiInstance),
            SystemAction.get(PropertiesAction.class)
        };
    }

    @Override
    public String getHtmlDisplayName() {
//        if (Kenai.getDefault().getUrl().toString().equals(kenaiInstance.getUrl())) {
//            return "<b>" + getDisplayName() + "</b>"; // NOI18N
//        }
        return super.getHtmlDisplayName();
    }

    public void propertyChange(PropertyChangeEvent evt) {
        fireDisplayNameChange("", getHtmlDisplayName());
    }

    @Override
    public void destroy() throws IOException {
        kenaiInstance.removePropertyChangeListener(this);
    }

    @Override
    public PropertySet[] getPropertySets() {
        return new PropertySet[] {properties.getSheetSet()};
    }

    @Override
    public boolean canCopy() {
        return false;
    }

}
